pygeodesy.lcc.Lcc

Package pygeodesy :: Module lcc :: Class Lcc |
[frames] | no frames]

# Class Lcc

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
                      Lcc

Lambert conformal conic East-/Northing location.

Instance Methods
__init__(self, e, n, h=0, conic=Conic(name='WRF_Lb', lat0=40, lon0=-97, par1=33, par2=45, E0=0`...`, **name) New Lcc Lamber conformal conic position. |
to3lld(self, datum=None) DEPRECATED, use method `toLatLon`. |
toLatLon(self, LatLon=None, datum=None, height=None, **LatLon_kwds) Convert this Lcc to an (ellipsoidal) geodetic point. |
toRepr(self, prec=0, fmt='[%s]', sep=', ', m=`'``m``'`, C=False, **unused) Return a string representation of this Lcc position. |
toStr(self, prec=0, sep=' ', m=`'``m``'`) Return a string representation of this Lcc position. |
Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| conic Get the conic projection (Conic).
| easting Get the easting (`meter`).
| height Get the height (`meter`).
| latlon Get the lat- and longitude in `degrees` (LatLon2Tuple).
| latlonheight Get the lat-, longitude and height (LatLon3Tuple`(lat, lon, height)`).
| latlonheightdatum Get the lat-, longitude in `degrees` with height and datum (LatLon4Tuple`(lat, lon, height, datum)`).
| northing Get the northing (`meter`).
| philam Get the lat- and longitude in `radians` (PhiLam2Tuple).
| philamheight Get the lat-, longitude in `radians` and height (PhiLam3Tuple`(phi, lam, height)`).
| philamheightdatum Get the lat-, longitude in `radians` with height and datum (PhiLam4Tuple`(phi, lam, height, datum)`).
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, e, n, h=0, conic=Conic(name='WRF_Lb', lat0=40, lon0=-97, par1=33, par2=45, E0=0`...`, **name) (Constructor) |
New Lcc Lamber conformal conic position. Arguments: `e` - Easting (`meter`). `n` - Northing (`meter`). `h` - Optional height (`meter`). `conic` - Optional, the conic projection (Conic). `name` - Optional `name=NN` (`str`). Returns: The Lambert location (Lcc). Raises: `LCCError` - Invalid `h` or invalid or negative `e` or `n`. `TypeError` - If `conic` is not Conic. Overrides: object.__init__

### to3lld (self, datum=None) |
DEPRECATED, use method `toLatLon`. Arguments: `datum` - Optional datum to use, otherwise use this `Lcc`'s conic.datum (`Datum`). Returns: A LatLonDatum3Tuple`(lat, lon, datum)`. Decorators: `@deprecated_method` Raises: `TypeError` - If `datum` is not ellipsoidal.

### toLatLon (self, LatLon=None, datum=None, height=None, **LatLon_kwds) |
Convert this Lcc to an (ellipsoidal) geodetic point. Arguments: `LatLon` - Optional, ellipsoidal class to return the geodetic point (`LatLon`) or `None`. `datum` - Optional datum to use, otherwise use this `Lcc`'s conic.datum (Datum, Ellipsoid, Ellipsoid2 or a_f2Tuple). `height` - Optional height for the point, overriding the default height (`meter`). `LatLon_kwds` - Optional, additional `LatLon` keyword arguments, ignored if `LatLon is None`. Returns: The point (`LatLon`) or if `LatLon is None`, a LatLon4Tuple`(lat, lon, height, datum)`. Raises: `TypeError` - If `LatLon` or `datum` is not ellipsoidal or not valid.

### toRepr (self, prec=0, fmt='[%s]', sep=', ', m=`'``m``'`, C=False, **unused) |
Return a string representation of this Lcc position. Arguments: `prec` - Number of (decimal) digits, unstripped (`int`). `fmt` - Enclosing backets format (`str`). `sep` - Optional separator between name:values (`str`). `m` - Optional unit of the height, default meter (`str`). `C` - Optionally, include name of conic and datum (`bool`). Returns: This Lcc as "[E:meter, N:meter, H:m, C:Conic.Datum]" (`str`). Overrides: named._Named.toRepr

### toStr (self, prec=0, sep=' ', m=`'``m``'`) |
Return a string representation of this Lcc position. Arguments: `prec` - Number of (decimal) digits, unstripped (`int`). `sep` - Optional separator to join (`str`) or `None` to return an unjoined `tuple` of `str`s. `m` - Optional height units, default `meter` (`str`). Returns: This Lcc as "easting nothing" in `meter` plus " height" suffixed with `m` if height is non-zero (`str`). Overrides: named._Named.toStr

Property Details

### conic Get the conic projection (Conic). Get method: conic(self) - Get the conic projection (Conic). Set method: conic(self, conic) - Set the conic projection (Conic). Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### easting Get the easting (`meter`). Get method: easting(self) - Get the easting (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### height Get the height (`meter`). Get method: height(self) - Get the height (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### latlon Get the lat- and longitude in `degrees` (LatLon2Tuple). Get method: latlon(self) - Get the lat- and longitude in `degrees` (LatLon2Tuple). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### latlonheight Get the lat-, longitude and height (LatLon3Tuple`(lat, lon, height)`). Get method: latlonheight(self) - Get the lat-, longitude and height (LatLon3Tuple`(lat, lon, height)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### latlonheightdatum Get the lat-, longitude in `degrees` with height and datum (LatLon4Tuple`(lat, lon, height, datum)`). Get method: latlonheightdatum(self) - Get the lat-, longitude in `degrees` with height and datum (LatLon4Tuple`(lat, lon, height, datum)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### northing Get the northing (`meter`). Get method: northing(self) - Get the northing (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### philam Get the lat- and longitude in `radians` (PhiLam2Tuple). Get method: philam(self) - Get the lat- and longitude in `radians` (PhiLam2Tuple). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### philamheight Get the lat-, longitude in `radians` and height (PhiLam3Tuple`(phi, lam, height)`). Get method: philamheight(self) - Get the lat-, longitude in `radians` and height (PhiLam3Tuple`(phi, lam, height)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### philamheightdatum Get the lat-, longitude in `radians` with height and datum (PhiLam4Tuple`(phi, lam, height, datum)`). Get method: philamheightdatum(self) - Get the lat-, longitude in `radians` with height and datum (PhiLam4Tuple`(phi, lam, height, datum)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.